@@ -35,6 +35,9 @@
 #include <kglobalaccel.h>
 #include <kglobalaccel.h>
 
+#include <QDBusInterface>
+#include <QDBusPendingCall>
+
 namespace PowerDevil {
 namespace BundledActions {
 
@@ -54,17 +57,17 @@ KeyboardBrightnessControl::KeyboardBrightnessControl(QObject* parent)
 
     QAction *globalAction = actionCollection->addAction("Increase Keyboard Brightness");
     globalAction->setText(i18nc("@action:inmenu Global shortcut", "Increase Keyboard Brightness"));
-    accel->setDefaultShortcut(globalAction, QList<QKeySequence>() << Qt::Key_KeyboardBrightnessUp);
+    accel->setGlobalShortcut(globalAction, Qt::Key_KeyboardBrightnessUp);
     connect(globalAction, SIGNAL(triggered(bool)), SLOT(increaseKeyboardBrightness()));
 
     globalAction = actionCollection->addAction("Decrease Keyboard Brightness");
     globalAction->setText(i18nc("@action:inmenu Global shortcut", "Decrease Keyboard Brightness"));
-    accel->setDefaultShortcut(globalAction, QList<QKeySequence>() << Qt::Key_KeyboardBrightnessDown);
+    accel->setGlobalShortcut(globalAction, Qt::Key_KeyboardBrightnessDown);
     connect(globalAction, SIGNAL(triggered(bool)), SLOT(decreaseKeyboardBrightness()));
 
     globalAction = actionCollection->addAction("Toggle Keyboard Backlight");
     globalAction->setText(i18nc("@action:inmenu Global shortcut", "Toggle Keyboard Backlight"));
-    accel->setDefaultShortcut(globalAction, QList<QKeySequence>() << Qt::Key_KeyboardLightOnOff);
+    accel->setGlobalShortcut(globalAction, Qt::Key_KeyboardLightOnOff);
     connect(globalAction, SIGNAL(triggered(bool)), SLOT(toggleKeyboardBacklight()));
 }
 
@@ -141,6 +144,16 @@ bool KeyboardBrightnessControl::loadAction(const KConfigGroup& config)
 
 void KeyboardBrightnessControl::showBrightnessOSD(int brightness)
 {
+    QDBusMessage msg = QDBusMessage::createMethodCall(
+        QLatin1Literal("org.kde.plasmashell"),
+        QLatin1Literal("/org/kde/osdService"),
+        QLatin1Literal("org.kde.osdService"),
+        QLatin1Literal("keyboardBrightnessChanged")
+    );
+
+    msg.setArguments(QList<QVariant>() << brightness);
+
+    QDBusConnection::sessionBus().asyncCall(msg);
 }
 
 void KeyboardBrightnessControl::onBrightnessChangedFromBackend(float brightness, PowerDevil::BackendInterface::BrightnessControlType type)
@@ -154,16 +167,19 @@ void KeyboardBrightnessControl::onBrightnessChangedFromBackend(float brightness,
 void KeyboardBrightnessControl::increaseKeyboardBrightness()
 {
     backend()->brightnessKeyPressed(BackendInterface::Increase, BackendInterface::Keyboard);
+    showBrightnessOSD(keyboardBrightness());
 }
 
 void KeyboardBrightnessControl::decreaseKeyboardBrightness()
 {
     backend()->brightnessKeyPressed(BackendInterface::Decrease, BackendInterface::Keyboard);
+    showBrightnessOSD(keyboardBrightness());
 }
 
 void KeyboardBrightnessControl::toggleKeyboardBacklight()
 {
     backend()->brightnessKeyPressed(BackendInterface::Toggle, BackendInterface::Keyboard);
+    showBrightnessOSD(keyboardBrightness());
 }
 
 int KeyboardBrightnessControl::keyboardBrightness() const
